==> qore-xml-module-1.3.tar.bz2: qore-xml-module-1.3/docs/xml/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore XML Module", "index.html", [
    [ "Introduction", "index.html#xmlintro", null ],
    [ "Module Option Constants", "index.html#optionconstants", null ],
    [ "Automatic XML Serialization and Deserialization", "index.html#serialization", null ],
    [ "XML-RPC", "index.html#XMLRPC", null ],
    [ "XML Constants", "index.html#constants", null ],
    [ "Function and Method Tags", "index.html#codetags", [
      [ "NOOP", "index.html#NOOP", null ],
      [ "RUNTIME_NOOP", "index.html#RUNTIME_NOOP", null ],
      [ "RET_VALUE_ONLY", "index.html#RET_VALUE_ONLY", null ],
      [ "CONSTANT", "index.html#CONSTANT", null ],
      [ "DEPRECATED", "index.html#DEPRECATED", null ]
    ] ],
    [ "Release Notes", "index.html#xmlreleasenotes", [
      [ "xml Module Version 1.3", "index.html#xml13", null ],
      [ "xml Module Version 1.2", "index.html#xml12", null ],
      [ "xml Module Version 1.1", "index.html#xml11", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
".html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-xml-module-1.4.1.tar.bz2: qore-xml-module-1.4.1/docs/xml/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore XML Module", "index.html", [
    [ "Introduction", "index.html#xmlintro", null ],
    [ "Module Option Constants", "index.html#optionconstants", null ],
    [ "Automatic XML Serialization and Deserialization", "index.html#serialization", [
      [ "Serializing and Deserializing XML Attributes", "index.html#xmlattributeserialization", null ],
      [ "Serializing and Deserializing XML Arrays", "index.html#xmlarrayserialization", null ],
      [ "Serializing and Deserializing XML Comments", "index.html#xmlcommentserialization", null ],
      [ "Serializing and Deserializing XML CDATA", "index.html#xmlcdataserialization", null ]
    ] ],
    [ "XML-RPC", "index.html#XMLRPC", null ],
    [ "XML Constants", "index.html#constants", null ],
    [ "Function and Method Tags", "index.html#codetags", [
      [ "NOOP", "index.html#NOOP", null ],
      [ "RUNTIME_NOOP", "index.html#RUNTIME_NOOP", null ],
      [ "RET_VALUE_ONLY", "index.html#RET_VALUE_ONLY", null ],
      [ "CONSTANT", "index.html#CONSTANT", null ],
      [ "DEPRECATED", "index.html#DEPRECATED", null ]
    ] ],
    [ "Release Notes", "index.html#xmlreleasenotes", [
      [ "xml Module Version 1.4.1", "index.html#xml141", null ],
      [ "xml Module Version 1.4", "index.html#xml14", null ],
      [ "xml Module Version 1.3.2", "index.html#xml132", null ],
      [ "xml Module Version 1.3.1", "index.html#xml131", null ],
      [ "xml Module Version 1.3", "index.html#xml13", null ],
      [ "xml Module Version 1.2", "index.html#xml12", null ],
      [ "xml Module Version 1.1", "index.html#xml11", null ]
    ] ],
    [ "XML Generation Options", "xml_generation_opts.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"index.html#xml132"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
